/**
  ******************************************************************************
  * @file    main.c
  * @author  Ac6
  * @version V1.0
  * @date    01-December-2013
  * @brief   Default main function.
  ******************************************************************************
*/

#include <stdlib.h>
#include "stm32f4xx.h"
#include "stm32f4xx_hal.h"
#include "stm32f4xx_hal_uart.h"
#include "stm32f429i_discovery.h"
#include "stm32f429i_discovery_lcd.h"
#include "stm32f429i_discovery_gyroscope.h"
#include "system_clocks.h"
#include "simpleLCD.h"
#include "random.h"
#include "serial.h"
#include "adc.h"

/* Private typedef -----------------------------------------------------------*/

/* Exported macro ------------------------------------------------------------*/

/* Private macro -----------------------
 * --------------------------------------*/
/* Private variables ---------------------------------------------------------*/

/* UART handler declaration */
UART_HandleTypeDef UartHandle;

static char str[30]={0};

/* Private function prototypes -----------------------------------------------*/
static void EXTILine0_Config(void);

/* Private functions ---------------------------------------------------------*/

int main(void){

  HAL_Init();

  /* Configure LED3 and LED4 */
  BSP_LED_Init(LED3);
  BSP_LED_Init(LED4);

  /* Configure the system clock to 180 MHz */
  SystemClock_Config();

  /* Configure EXTI Line0 (connected to PA0 pin) in interrupt mode */
  EXTILine0_Config();

  ADC_Init();

  LCD_Init();
  Serial_Init();
  Serial_Send((uint8_t*)"UART Start OK \n ", 15);
  LCD_SetFont(FONT16);
  LCD_PrintXY(6,1,"Witam ADC !");

  HAL_GPIO_WritePin(LED3_GPIO_PORT,LED3_PIN,GPIO_PIN_RESET);

  BSP_LED_Off(LED3);
  BSP_LED_Off(LED4);

  /* Infinite loop */
  while(1){
    BSP_LED_Toggle(LED3); //czyli PG13
    if( HAL_ADC_Start(&hadc1) != HAL_OK){
    		 Serial_Send((uint8_t*)"ADC Error 1 ! \n ",15);
    		 _Error_Handler(__FILE__, __LINE__);
    }
    if(HAL_ADC_PollForConversion(&hadc1,500) != HAL_OK){
    	Serial_Send((uint8_t*)"ADC Error 2 ! \n ",15);
     	 _Error_Handler(__FILE__, __LINE__);
    }
    uint32_t val = HAL_ADC_GetValue(&hadc1);

    snprintf(str,30, "val = %5lu  ",val);
    LCD_PrintXY(1,3, str);

	// ADC1-INUT_5 : Pin PA5
    //  3,3V/4095 ~=> 0,8059 mV
    val = val *8059/10000;
//    snprintf(str,30, "Val=%3lu,%03lu[V]   ",val/1000,val%1000);
//    LCD_PrintXY(1,5, str);
//    snprintf(str,30, "val=%3lu,%03lu[V] \n   ",val/1000,val%1000);
//    Serial_Send((uint8_t*)str,16);

    HAL_Delay(500);//


  }
}

/**
  * @brief  Configures EXTI Line0 (connected to PA0 pin) in interrupt mode
  * @param  None
  * @retval None
  */
static void EXTILine0_Config(void)
{
  GPIO_InitTypeDef   GPIO_InitStructure;

  /* Enable GPIOA clock */
  __HAL_RCC_GPIOA_CLK_ENABLE();

  /* Configure PA0 pin as input floating */
  GPIO_InitStructure.Mode = GPIO_MODE_IT_FALLING;
  GPIO_InitStructure.Pull = GPIO_NOPULL;
  GPIO_InitStructure.Pin = GPIO_PIN_0;
  HAL_GPIO_Init(GPIOA, &GPIO_InitStructure);

  /* Enable and set EXTI Line0 Interrupt to the lowest priority */
  HAL_NVIC_SetPriority(EXTI0_IRQn, 2, 0);
  HAL_NVIC_EnableIRQ(EXTI0_IRQn);
}

/**
  * @brief EXTI line detection callbacks
  * @param GPIO_Pin: Specifies the pins connected EXTI line
  * @retval None
  */
void HAL_GPIO_EXTI_Callback(uint16_t GPIO_Pin)
{
  if(GPIO_Pin == KEY_BUTTON_PIN)
  {
    //*** TU wpisz reakcję na przycisk
    // np.
    /* Toggle LED3 */
    //BSP_LED_Toggle(LED3);
	//startTime = HAL_GetTick();
  }
}

/*
void HAL_SYSTICK_Callback(void)
{
  // tu wpisz obsługę SysTick
  // czyli co ma byc wykonywane co 1[ms]

}

*/

void _Error_Handler(char * file, int line)
{
  /* User can add his own implementation to report the HAL error return state */
  char s1[30]={0};
  snprintf(s1,30,"E:%s:%d  ", file, line);
  LCD_PrintXY(1,18,s1);
  while(1)
  {
  }
}


